@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -168,7 +168,7 @@ public final class SpamAssassinSpamHandler extends SpamHandler {
 
     private static final SpamAssassinSpamHandler instance = new SpamAssassinSpamHandler();
     
-//    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(PropertyHandler.class);
+//    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(PropertyHandler.class));
 
     private static final String NAME = "SpamAssassin";
 
@@ -218,9 +218,10 @@ public final class SpamAssassinSpamHandler extends SpamHandler {
         final MailAccess<?, ?> mailAccess = mailService.getMailAccess(session, accountId);
         mailAccess.connect();
         try {
-
-            final String confirmedSpamFullname = mailAccess.getFolderStorage().getConfirmedSpamFolder();
-            mailAccess.getMessageStorage().copyMessages(fullname, confirmedSpamFullname, mailIDs, true);
+            if (isCreateConfirmedSpam()) {
+                final String confirmedSpamFullname = mailAccess.getFolderStorage().getConfirmedSpamFolder();
+                mailAccess.getMessageStorage().copyMessages(fullname, confirmedSpamFullname, mailIDs, true);
+            }
             final SpamdSettings spamdSettings = getSpamdSettings(session, PropertyHandler.getInstance());
             if (null != spamdSettings) {
                 final MailMessage[] mails = mailAccess.getMessageStorage().getMessages(fullname, mailIDs, new MailField[]{MailField.FULL});
@@ -241,7 +242,9 @@ public final class SpamAssassinSpamHandler extends SpamHandler {
     private void copyMessagesToConfirmedHamAndInbox(final UnwrapParameter paramObject, final String[] plainIDsArr, final String confirmedHamFullname, final SpamdSettings spamdSettings) throws MailException {
         final MailAccess<?, ?> mailAccess = paramObject.getMailAccess();
         final String spamFullname = paramObject.getSpamFullname();
-        mailAccess.getMessageStorage().copyMessages(spamFullname, confirmedHamFullname, plainIDsArr, false);
+        if (isCreateConfirmedHam()) {
+            mailAccess.getMessageStorage().copyMessages(spamFullname, confirmedHamFullname, plainIDsArr, false);
+        }
         if (null != spamdSettings) {
             final MailMessage[] mails = mailAccess.getMessageStorage().getMessages(spamFullname, plainIDsArr, new MailField[]{MailField.FULL});
             spamdMessageProcessing(mails, spamdSettings, false);
